@@ -6,7 +6,7 @@
 ;; Author: Carsten Dominik <carsten at orgmode dot org>
 ;; Keywords: outlines, hypermedia, calendar, wp
 ;; Homepage: http://orgmode.org
-;; Version: 7.4
+;; Version: 7.6
 ;;
 ;; This file is part of GNU Emacs.
 ;;
@@ -52,9 +52,9 @@
     (let (link desc)
       (setq link (org-make-link "info:"
 				(file-name-nondirectory Info-current-file)
-				":" Info-current-node))
+				"#" Info-current-node))
       (setq desc (concat (file-name-nondirectory Info-current-file)
-			 ":" Info-current-node))
+			 "#" Info-current-node))
       (org-store-link-props :type "info" :file Info-current-file
 			    :node Info-current-node
 			    :link link :desc desc)
@@ -67,7 +67,7 @@
 
 (defun org-info-follow-link (name)
   "Follow an Info file and node link specified by NAME."
-  (if (or (string-match "\\(.*\\)::?\\(.*\\)" name)
+  (if (or (string-match "\\(.*\\)[#:]:?\\(.*\\)" name)
           (string-match "\\(.*\\)" name))
       (progn
 	(require 'info)
